@@ -1054,10 +1054,11 @@ def get_template(
                         "Value": "OrganizationAccountAccessRole",
                     },
                     {"Type": "PLAINTEXT", "Name": "IAM_ROLE_ARNS", "Value": ""},
+                    {"Type": "PLAINTEXT", "Name": "OPTIONS", "Value": ""},
                 ],
             ),
             Source=codebuild.Source(
-                BuildSpec="version: 0.2\nphases:\n  install:\n    runtime-versions:\n      python: 3.7\n    commands:\n      - pip install aws-service-catalog-puppet\n  build:\n    commands:\n      - servicecatalog-puppet bootstrap-spokes-in-ou $OU_OR_PATH $IAM_ROLE_NAME $IAM_ROLE_ARNS\nartifacts:\n  files:\n    - results/*/*\n    - output/*/*\n  name: BootstrapProject\n",
+                BuildSpec="version: 0.2\nphases:\n  install:\n    runtime-versions:\n      python: 3.7\n    commands:\n      - pip install aws-service-catalog-puppet\n  build:\n    commands:\n      - servicecatalog-puppet bootstrap-spokes-in-ou $OU_OR_PATH $IAM_ROLE_NAME $IAM_ROLE_ARNS ${OPTIONS}\nartifacts:\n  files:\n    - results/*/*\n    - output/*/*\n  name: BootstrapProject\n",
                 Type="NO_SOURCE",
             ),
             Description="Bootstrap all the accounts in an OU",
@@ -1092,6 +1093,7 @@ def get_template(
                         "Name": "ASSUMABLE_ROLE_IN_ROOT_ACCOUNT",
                         "Value": "CHANGE_ME",
                     },
+                    {"Type": "PLAINTEXT", "Name": "OPTIONS", "Value": "CHANGE_ME",},
                 ],
             ),
             Source=codebuild.Source(
@@ -1102,7 +1104,7 @@ def get_template(
                             install=install_spec,
                             build={
                                 "commands": [
-                                    "servicecatalog-puppet bootstrap-spoke-as ${PUPPET_ACCOUNT_ID} ${ASSUMABLE_ROLE_IN_ROOT_ACCOUNT} ${ORGANIZATION_ACCOUNT_ACCESS_ROLE_ARN}"
+                                    "servicecatalog-puppet bootstrap-spoke-as ${PUPPET_ACCOUNT_ID} ${ASSUMABLE_ROLE_IN_ROOT_ACCOUNT} ${ORGANIZATION_ACCOUNT_ACCESS_ROLE_ARN} ${OPTIONS}"
                                 ]
                             },
                         ),
