@@ -100,6 +100,9 @@ def generate_dependency_task(
     from servicecatalog_puppet.workflow.service_control_policies import (
         service_control_policies_task,
     )
+    from servicecatalog_puppet.workflow.tag_policies import (
+        tag_policies_task,
+    )
 
     common_args = dict(
         manifest_file_path=manifest_file_path, puppet_account_id=puppet_account_id,
@@ -201,6 +204,16 @@ def generate_dependency_task(
                 f"Affinity of {depends_on.get(constants.AFFINITY)} is not supported for this action"
             )
 
+    elif depends_on.get("type") == constants.TAG_POLICY:
+        if depends_on.get(constants.AFFINITY) == constants.TAG_POLICY:
+            return tag_policies_task.TagPoliciesTask(
+                **common_args, tag_policies_name=depends_on.get("name"),
+            )
+        else:
+            raise Exception(
+                f"Affinity of {depends_on.get(constants.AFFINITY)} is not supported for this action"
+            )
+
     elif (
         is_running_in_hub and depends_on.get("type") == constants.SPOKE_LOCAL_PORTFOLIO
     ):
